// $Id: enum_point_locator_type.h 3874 2010-07-02 21:57:26Z roystgnr $

// The libMesh Finite Element Library.
// Copyright (C) 2002-2008 Benjamin S. Kirk, John W. Peterson, Roy H. Stogner
  
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
  
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA



#ifndef __enum_point_locator_type_h__
#define __enum_point_locator_type_h__

// ------------------------------------------------------------
// enum PointLocatorType definition
namespace libMeshEnums {
  
  /**
   * \enum MeshEnums::PointLocatorType defines an \p enum for the types
   * of point locators (given a point with global coordinates,
   * locate the corresponding element in space) available in libMesh.
   */
  enum PointLocatorType {TREE = 0,
			 LIST,
			 INVALID_LOCATOR};
}

using namespace libMeshEnums;

#endif // #ifndef __enum_point_locator_type_h__




